@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply arpeggiation patterns to groups of notes
 
-our $VERSION = '0.0203';
+our $VERSION = '0.0300';
 
 use Moo;
 use strictures 2;
@@ -63,14 +63,15 @@ sub arp {
 
     # compute the arp durations
     my $x = $duration * TICKS;
-    my $z = sprintf '%0.f', $x / @$notes;
+    my $z = sprintf '%0.f', $x / @$pattern;
     print "Durations: $x, $z\n" if $self->verbose;
     $z = 'd' . $z;
 
     my @arp;
     for my $i (1 .. $repeats) {
-        for my $j (1 .. @$notes) {
-            push @arp, [ $z, $notes->[ $pat->current ] ];
+        for my $j (1 .. @$pattern) {
+            push @arp, [ $z, $notes->[ $pat->current ] ]
+                if $pat->current < @$notes;
             $pat->next;
         }
     }
@@ -112,7 +113,7 @@ Music::MelodicDevice::Arpeggiation - Apply arpeggiation patterns to groups of no
 
 =head1 VERSION
 
-version 0.0203
+version 0.0300
 
 =head1 SYNOPSIS
 
